@@ -1,7 +1,8 @@
+from dataclasses import asdict
 from datetime import datetime
+from functools import partial
 import numpy as np
 import random
-import time
 
 from paramga.plot import (
     plot_loss,
@@ -171,6 +172,7 @@ def iteration(
     process_outputs: Callable[[np.ndarray], np.ndarray] = None,
     parallel=False,
     func_kwargs: dict=None,
+    TIMEOUT: float = 100,
 ) -> IterationState:
     """Run paramga iteration.
 
@@ -210,7 +212,7 @@ def iteration(
     # Run and get losses
     input_args = [(params, input_data) for params in parameters]
 
-    run_func = get_outputs_parallel if parallel else get_outputs
+    run_func = partial(get_outputs_parallel, TIMEOUT=TIMEOUT) if parallel else get_outputs
     outputs = run_func(func, input_args, _func_kwargs)
     outputs_processed = np.array([process_outputs(o)
                                  for o in outputs]) if process_outputs else outputs
@@ -424,6 +426,7 @@ class Runner:
         verbose: bool = False,
         parallel: bool = False,
         seed: int = 0,
+        timeout: float = 100,
     ):
         """Create Runner instance.
 
@@ -455,6 +458,8 @@ class Runner:
             Run iterations in parallel, by default False
         seed : int, optional
             The random seed to use, by default 0
+        timeout: float
+            Timeout for each parallel model run.
 
         """
         self.param_base = param_base
@@ -469,6 +474,7 @@ class Runner:
         self.max_iterations = max_iterations
         self.verbose = verbose
         self.parallel = parallel
+        self.timeout = timeout
         self.seed = seed
         self.stats = RunStats(None)
 
@@ -514,6 +520,7 @@ class Runner:
             process_outputs=self.process_outputs,
             parallel=self.parallel,
             func_kwargs=self.func_kwargs,
+            TIMEOUT=self.timeout,
         )
         self.iteration_state = new_state
         if self._store_iterations:
@@ -541,6 +548,9 @@ class Runner:
         """Run the model on the best parameters from the iteration state."""
         return self.func(self.param_base, self.input_data, **self.func_kwargs)
 
+    def iteration_state_dump(self):
+        return asdict(self.iteration_state)
+
     def plot(self, key='loss', ax=None, fig=None):
         if len(self.history) == 0:
             raise ValueError('Must run with store_iteraions on to create plots')
