@@ -286,7 +286,8 @@ class TestRunCls:
         }
 
     def demo_model(self):
-        def model(params, data):
+        def model(params, data, abc=None):
+            assert abc # example kwarg
             return np.array([d * params['foo'] for d in data])
         return model
 
@@ -308,6 +309,8 @@ class TestRunCls:
             "foo": 40,
             "bar": 360,
         }
+    def demo_kwargs(self):
+        return dict(abc=123)
 
     def _default_instance(self, **kwargs):
         default_args = dict(
@@ -317,6 +320,7 @@ class TestRunCls:
             loss_func=self.demo_loss_function(),
             input_data=self.demo_data(),
             process_outputs=self.demo_process_outputs(),
+            func_kwargs=self.demo_kwargs(),
             population=8,
             max_iterations=100,
             tolerance=0.05,
@@ -447,7 +451,7 @@ class TestRunCls:
         )
         runner.store_iterations()
         runner.run()
-        print(runner.func(runner.iteration_state.best_parameters, runner.input_data))
+        print(runner.func(runner.iteration_state.best_parameters, runner.input_data, **self.demo_kwargs()))
         observed_data = np.array(runner.input_data)
         runner.plot_compare_with_observed(observed_data)
 
@@ -474,6 +478,21 @@ class TestRunCls:
         assert runner.iteration_state.lowest_loss != 198
         assert runner.iteration_state.lowest_loss == 108
 
+    def test_can_get_initial_output(self):
+        tolerance = 0.00000001
+        runner = self._default_instance(
+            tolerance=tolerance,
+            max_iterations=100,
+        )
+        runner.store_iterations()
+        runner.run()
+
+        initial_output = runner.get_initial_model_output()
+        expected_initial_output = self.demo_model()(self.demo_state(), self.demo_data(), **self.demo_kwargs())
+        assert len(initial_output) == len(expected_initial_output)
+        for a, b in zip(initial_output, expected_initial_output):
+            assert a == b
+
     def test_can_get_best_output(self):
         tolerance = 0.00000001
         runner = self._default_instance(
@@ -484,7 +503,7 @@ class TestRunCls:
         runner.run()
 
         best_output = runner.get_best_model_output()
-        expected_best_output = self.demo_model()(self.demo_best_params(), self.demo_data())
+        expected_best_output = self.demo_model()(self.demo_best_params(), self.demo_data(), **self.demo_kwargs())
         assert len(best_output) == len(expected_best_output)
         for a, b in zip(best_output, expected_best_output):
             assert a == b
